@@ -1,3 +1,5 @@
+import os
+
 from office365.runtime.client_object_collection import ClientObjectCollection
 from office365.runtime.queries.create_entity_query import CreateEntityQuery
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
@@ -15,6 +17,22 @@ class FolderCollection(ClientObjectCollection):
         """
         return super(FolderCollection, self).get()
 
+    def ensure_folder_path(self, path):
+        """
+        Function to create a folder
+        :type path: string
+        :param path: relative server URL (path) to a folder
+        """
+
+        url_component = os.path.normpath(path).split(os.path.sep)
+        url_component = [part for part in url_component if part]
+        if not url_component:
+            raise NotADirectoryError("Wrong relative URL provided")
+        child_folder = self
+        for url_part in url_component:
+            child_folder = child_folder.add(url_part)
+        return child_folder
+
     def add(self, server_relative_url):
         """Adds the folder that is located at the specified URL to the collection.
 
