@@ -7,7 +7,9 @@ from office365.sharepoint.changes.change_collection import ChangeCollection
 from office365.sharepoint.lists.list import List
 from office365.sharepoint.principal.user import User
 from office365.sharepoint.recyclebin.recycleBinItemCollection import RecycleBinItemCollection
+from office365.sharepoint.sites.sph_site import SPHSite
 from office365.sharepoint.webs.web import Web
+from office365.sharepoint.webs.web_template_collection import WebTemplateCollection
 
 
 class Site(ClientObject):
@@ -16,6 +18,22 @@ class Site(ClientObject):
     def __init__(self, context):
         super(Site, self).__init__(context, ResourcePath("Site", None))
 
+    def is_valid_home_site(self):
+        result = ClientResult(None)
+
+        def _site_loaded():
+            SPHSite.is_valid_home_site(self.context, self.url, result)
+        self.ensure_property("Url", _site_loaded)
+        return result
+
+    def set_as_home_site(self):
+        result = ClientResult(None)
+
+        def _site_loaded():
+            self.result = SPHSite.set_as_home_site(self.context, self.url, result)
+        self.ensure_property("Url", _site_loaded)
+        return result
+
     def get_changes(self, query):
         """Returns the collection of all changes from the change log that have occurred within the scope of the site,
         based on the specified query.
@@ -37,6 +55,41 @@ class Site(ClientObject):
         self.context.add_query(qry)
         return result
 
+    def get_web_templates(self, lcid=1033, override_compat_level=0):
+        """
+        Returns the collection of site definitions that are available for creating
+            Web sites within the site collection.<99>
+
+        :param int lcid: A 32-bit unsigned integer that specifies the language of the site definitions that are
+            returned from the site collection.
+        :param int override_compat_level: Specifies the compatibility level of the site (2)
+            to return from the site collection. If this value is 0, the compatibility level of the site (2) is used.
+        :return:
+        """
+        params = {
+            "LCID": lcid,
+            "overrideCompatLevel": override_compat_level
+        }
+        return_type = WebTemplateCollection(self.context,
+                                            ResourcePathServiceOperation("GetWebTemplates", params, self.resource_path))
+
+        qry = ServiceOperationQuery(self, "GetWebTemplates", params, None, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
+    def join_hub_site(self, hubSiteId, approvalToken, approvalCorrelationId):
+        params = {
+            "hubSiteId": hubSiteId,
+            "approvalToken": approvalToken,
+            "approvalCorrelationId": approvalCorrelationId
+        }
+        return_type = WebTemplateCollection(self.context,
+                                            ResourcePathServiceOperation("GetWebTemplates", params, self.resource_path))
+
+        qry = ServiceOperationQuery(self, "JoinHubSite", params, None, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     @staticmethod
     def get_url_by_id(context, site_id, stop_redirect=False):
         """Gets Site Url By Id
@@ -54,6 +107,10 @@ class Site(ClientObject):
         context.add_query(qry)
         return result
 
+    @staticmethod
+    def get_url_by_id_for_web(context):
+        pass
+
     @staticmethod
     def exists(context, url):
         """Determine whether site exists
@@ -91,6 +148,17 @@ class Site(ClientObject):
         else:
             return User(self.context, ResourcePath("owner", self.resource_path))
 
+    @property
+    def url(self):
+        return self.properties.get('Url', None)
+
+    @property
+    def id(self):
+        """
+        :rtype: str
+        """
+        return self.properties.get("Id", None)
+
     @property
     def recycleBin(self):
         """Get recycle bin"""
