@@ -4,7 +4,6 @@ from tests import random_seed
 from tests.sharepoint.sharepoint_case import SPTestCase
 
 from office365.sharepoint.changes.change_collection import ChangeCollection
-from office365.sharepoint.changes.change_query import ChangeQuery
 from office365.sharepoint.files.move_operations import MoveOperations
 from office365.sharepoint.folders.folder import Folder
 from office365.sharepoint.lists.list import List
@@ -37,7 +36,7 @@ class TestSharePointFolder(SPTestCase):
 
         folder_url = parent_folder.serverRelativeUrl
         folder_object = self.client.web.get_folder_by_server_relative_url(folder_url).get().execute_query()
-        self.assertTrue(folder_object.properties["ServerRelativeUrl"], folder_url)
+        self.assertTrue(folder_object.serverRelativeUrl, folder_url)
         folders = folder_object.folders.get().execute_query()
         for child_folder in folders:
             self.assertIsNotNone(child_folder.resource_path)
@@ -48,75 +47,81 @@ class TestSharePointFolder(SPTestCase):
     def test2_create_folder(self):
         folder_new = self.__class__.target_list.rootFolder.folders.add(self.__class__.target_folder_name)\
             .execute_query()
-        self.assertTrue(folder_new.properties["Exists"])
+        self.assertTrue(folder_new.exists)
         self.__class__.target_folder = folder_new
 
-    def test3_get_folder_by_id(self):
-        folder_id = self.__class__.target_folder.properties['UniqueId']
+    def test4_get_folder_by_id(self):
+        folder_id = self.__class__.target_folder.unique_id
         folder = self.client.web.get_folder_by_id(folder_id).execute_query()
         self.assertIsNotNone(folder.resource_path)
 
-    def test4_update_folder(self):
-        folder_to_update = self.__class__.target_list.rootFolder.folders.get_by_url(self.__class__.target_folder_name)
-        self.__class__.target_folder_name = "_Archive_" + str(randint(0, 1000))
-        folder_to_update.rename(self.__class__.target_folder_name).execute_query()
+    def test5_update_folder_properties(self):
+        list_item = self.__class__.target_folder.list_item_all_fields
+        list_item.set_property("Title", "New folder title").update().execute_query()
 
-        result = self.__class__.target_list.rootFolder.folders\
-            .filter("Name eq '{0}'".format(self.__class__.target_folder_name))\
-            .get()\
-            .execute_query()
-        self.assertEqual(len(result), 1)
-
-    def test5_copy_folder(self):
-        folder_to_copy = self.__class__.target_list.rootFolder.folders.get_by_url(self.__class__.target_folder_name)
-        # 1.make sure a source folder contains at least one file
-        uploaded_file = folder_to_copy.upload_file("sample.txt", "Some content goes here...")
-        self.client.load(folder_to_copy, ["Files"])
+    def test6_upload_file_into_folder(self):
+        uploaded_file = self.__class__.target_folder.upload_file("sample.txt", "Some content goes here...")
         self.client.execute_query()
         self.assertIsNotNone(uploaded_file.serverRelativeUrl)
-        self.assertGreater(len(folder_to_copy.files), 0)
 
-        # 2.ensure a target folder exists
+    def test7_get_folder_files(self):
+        folder = self.__class__.target_folder
+        self.client.load(folder, ["Files"])
+        self.client.execute_query()
+        self.assertGreater(len(folder.files), 0)
+
+    def test8_copy_folder(self):
+        # ensure a target folder exists
         folder_name = "Copy_" + str(randint(0, 1000))
         folder_to = self.__class__.target_list.rootFolder.add(folder_name)
         self.client.execute_query()
         self.assertIsNotNone(folder_to.serverRelativeUrl)
 
         # 3. copy folder with files
-        folder_to_copy.copyto(folder_to.properties['ServerRelativeUrl'], True)
+        self.__class__.target_folder.copy_to(folder_to.serverRelativeUrl, True)
         self.client.load(folder_to, ["Files"])
         self.client.execute_query()
         self.assertGreater(len(folder_to.files), 0)
 
-    def test6_move_folder(self):
+    def test9_rename_folder(self):
+        folder_to_rename = self.__class__.target_folder
+        self.__class__.target_folder_name = "_Archive_" + str(randint(0, 1000))
+        target_folder = folder_to_rename.rename(self.__class__.target_folder_name).get().execute_query()
+        self.assertEqual(target_folder.name, self.__class__.target_folder_name)
+
+    def test_10_find_folder(self):
+        result = self.__class__.target_list.rootFolder.folders \
+            .filter("Name eq '{0}'".format(self.__class__.target_folder_name)) \
+            .get() \
+            .execute_query()
+        self.assertEqual(len(result), 1)
+
+    def test_11_move_folder(self):
         folder = self.__class__.target_list.rootFolder.folders.get_by_url(self.__class__.target_folder_name)
         folder_name = "Move_" + str(randint(0, 1000))
-        folder_to = self.__class__.target_list.rootFolder.add(folder_name)
-        self.client.execute_query()
+        folder_to = self.__class__.target_list.rootFolder.add(folder_name).execute_query()
+        self.assertIsNotNone(folder_to.serverRelativeUrl)
+        folder.move_to(folder_to.properties['ServerRelativeUrl'], MoveOperations.overwrite).execute_query()
         self.assertIsNotNone(folder_to.serverRelativeUrl)
 
-        folder.moveto(folder_to.properties['ServerRelativeUrl'], MoveOperations.overwrite)
-        self.client.execute_query()
-        self.assertIsNotNone(folder_to.serverRelativeUrl)
-
-    def test7_recycle_folder(self):
+    def test_12_recycle_folder(self):
         folder_to_recycle = self.__class__.target_list.rootFolder.folders.get_by_url(self.__class__.target_folder_name)
         result = folder_to_recycle.recycle()
         self.client.execute_query()
         self.assertIsNotNone(result.value)
         self.__class__.deleted_folder_guid = result.value
 
-    def test8_restore_folder(self):
+    def test_13_restore_folder(self):
         recycle_item = self.client.web.recycleBin.get_by_id(self.__class__.deleted_folder_guid)
         recycle_item.restore().execute_query()
 
-    def test_10_get_folder_changes(self):
+    def test_14_get_folder_changes(self):
         folder = self.__class__.target_list.rootFolder.folders.get_by_url(self.__class__.target_folder_name)
-        changes = folder.list_item_all_fields.get_changes(ChangeQuery(item=True)).execute_query()
+        changes = folder.get_changes().execute_query()
         self.assertIsInstance(changes, ChangeCollection)
-        self.assertGreater(len(changes), 0)
+        self.assertGreaterEqual(len(changes), 0)
 
-    def test_11_delete_folder(self):
+    def test_15_delete_folder(self):
         folder_to_delete = self.__class__.target_list.rootFolder.folders.get_by_url(self.__class__.target_folder_name)
         folder_to_delete.delete_object().execute_query()
 
